@@ -3,13 +3,10 @@ use strict;
 use warnings;
 use parent qw/Skype::Any::Object/;
 
-sub property { shift->_property('USER', @_) }
-sub alter    { shift->_alter('USER', @_) }
+sub property { shift->SUPER::property('USER', @_) }
+sub alter    { shift->SUPER::alter('USER', @_) }
 
-for my $property (qw/hascallequipment is_video_capable is_voicemail_capable isauthorized isblocked can_leave_vm is_cf_active/) {
-    no strict 'refs';
-    *{$property} = sub { $_[0]->_boolean($property) };
-}
+__PACKAGE__->_mk_bool_property(qw/hascallequipment is_video_capable is_voicemail_capable isauthorized isblocked can_leave_vm is_cf_active/);
 
 sub create_chat {
     my $self = shift;
@@ -33,23 +30,25 @@ Skype::Any::Object::User - User object for Skype::Any
 
 =head1 SYNOPSIS
 
-    use Skype::Any;
+  use Skype::Any;
 
-    my $skype = Skype::Any->new;
-    my $user = $skype->user('echo123');
-    my $users = $skype->user('echo123, t.akiym');
+  my $skype = Skype::Any->new;
+  my $user = $skype->user('echo123');
+  my $users = $skype->user('echo123, t.akiym');
 
 =head1 METHODS
 
-=head2 C<create_chat>
+=over 4
+
+=item C<< $user->create_chat() >>
 
 Create new instance of L<Skype::Any::Object::Chat>.
 
-=head2 C<chat>
+=item C<< $user->chat() >>
 
-Alias for C<create_chat>.
+Alias for C<< $user->create_chat >>.
 
-=head2 C<property>
+=item C<< $user->property($property[, $value]) >>
 
 =over 4
 
@@ -107,8 +106,8 @@ Alias for C<create_chat>.
 
 =back
 
-=head1 SEE ALSO
+=item C<< $user->alter($action[, $value]) >>
 
-L<Skype::Any::Object>
+=back
 
 =cut
